@@ -199,6 +199,9 @@ typedef struct {
 	gboolean update_dropped_files;  /* the update flag of the add 
 					 * operation.  */
 
+	gboolean extracting_dragged_files;
+	gboolean extracting_dragged_files_interrupted;
+
 	/* progress dialog data */
 
 	GtkWidget *progress_dialog;
@@ -307,6 +310,8 @@ GList *    window_get_file_list_pattern     (FRWindow    *window,
 
 /**/
 
+void       window_stop                      (FRWindow    *window);
+
 void       window_start_activity_mode       (FRWindow    *window);
 
 void       window_stop_activity_mode        (FRWindow    *window);
